class CosmBlock:
    def __init__(self):
        self.height = None
        self.hash = None
        self.last_block_hash = None
        self.data_hash = None
        self.proposer = None
        self.num_txs = None
        self.time = None
